Struct staging_xcm::DoubleEncoded
source · pub struct DoubleEncoded<T> { /* private fields */ }Expand description
Wrapper around the encoded and decoded versions of a value. Caches the decoded value once computed.
Implementations
sourceimpl<T> DoubleEncoded<T>
impl<T> DoubleEncoded<T>
pub fn into<S>(self) -> DoubleEncoded<S>
pub fn from<S>(e: DoubleEncoded<S>) -> Self
sourceimpl<T: Decode> DoubleEncoded<T>
impl<T: Decode> DoubleEncoded<T>
sourcepub fn ensure_decoded(&mut self) -> Result<&T, ()>
pub fn ensure_decoded(&mut self) -> Result<&T, ()>
Decode the inner encoded value and store it.
Returns a reference to the value in case of success and Err(()) in case the decoding
fails.
sourcepub fn take_decoded(&mut self) -> Result<T, ()>
pub fn take_decoded(&mut self) -> Result<T, ()>
Move the decoded value out or (if not present) decode encoded.