Struct staging_xcm::v2::MultiAsset
source · pub struct MultiAsset {
pub id: AssetId,
pub fun: Fungibility,
}Fields
id: AssetIdfun: FungibilityImplementations
sourceimpl MultiAsset
impl MultiAsset
pub fn is_fungible(&self, maybe_id: Option<AssetId>) -> bool
pub fn is_non_fungible(&self, maybe_id: Option<AssetId>) -> bool
sourcepub fn prepend_with(&mut self, prepend: &MultiLocation) -> Result<(), ()>
pub fn prepend_with(&mut self, prepend: &MultiLocation) -> Result<(), ()>
Prepend a MultiLocation to a concrete asset, giving it a new root location.
sourcepub fn reanchor(
&mut self,
target: &MultiLocation,
ancestry: &MultiLocation
) -> Result<(), ()>
pub fn reanchor( &mut self, target: &MultiLocation, ancestry: &MultiLocation ) -> Result<(), ()>
Mutate the location of the asset identifier if concrete, giving it the same location
relative to a target context. The local context is provided as ancestry.
sourcepub fn reanchored(
self,
target: &MultiLocation,
ancestry: &MultiLocation
) -> Result<Self, ()>
pub fn reanchored( self, target: &MultiLocation, ancestry: &MultiLocation ) -> Result<Self, ()>
Mutate the location of the asset identifier if concrete, giving it the same location
relative to a target context. The local context is provided as ancestry.
sourcepub fn contains(&self, inner: &MultiAsset) -> bool
pub fn contains(&self, inner: &MultiAsset) -> bool
Returns true if self is a super-set of the given inner.