Struct staging_xcm::v2::MultiAssets

source ·
pub struct MultiAssets(/* private fields */);
A Vec of MultiAssets. There may be no duplicate fungible items in here and when decoding, they must be sorted.

Implementations

source

impl MultiAssets

source

pub fn new() -> Self

A new (empty) value.

source

pub fn from_sorted_and_deduplicated(r: Vec<MultiAsset>) -> Result<Self, ()>

Create a new instance of MultiAssets from a Vec<MultiAsset> whose contents are sorted and which contain no duplicates.

Returns Ok if the operation succeeds and Err if r is out of order or had duplicates. If you can’t guarantee that r is sorted and deduplicated, then use From::<Vec<MultiAsset>>::from which is infallible.

source

pub fn from_sorted_and_deduplicated_skip_checks(r: Vec<MultiAsset>) -> Self

Create a new instance of MultiAssets from a Vec<MultiAsset> whose contents are sorted and which contain no duplicates.

In release mode, this skips any checks to ensure that r is correct, making it a negligible-cost operation. Generally though you should avoid using it unless you have a strict proof that r is valid.

In test mode, this checks anyway and panics on fail.

source

pub fn push(&mut self, a: MultiAsset)

Add some asset onto the list, saturating. This is quite a laborious operation since it maintains the ordering.

source

pub fn is_none(&self) -> bool

Returns true if this definitely represents no asset.

source

pub fn contains(&self, inner: &MultiAsset) -> bool

Returns true if self is a super-set of the given inner.

source

pub fn drain(self) -> Vec<MultiAsset>

Consume self and return the inner vec.

source

pub fn inner(&self) -> &Vec<MultiAsset>

Return a reference to the inner vec.

source

pub fn len(&self) -> usize

Return the number of distinct asset instances contained.

source

pub fn prepend_with(&mut self, prefix: &MultiLocation) -> Result<(), ()>

Prepend a MultiLocation to any concrete asset items, giving it a new root location.

source

pub fn reanchor( &mut self, target: &MultiLocation, ancestry: &MultiLocation ) -> Result<(), ()>

Mutate the location of the asset identifier if concrete, giving it the same location relative to a target context. The local context is provided as ancestry.

source

pub fn get(&self, index: usize) -> Option<&MultiAsset>

Return a reference to an item at a specific index or None if it doesn’t exist.